@@ -1,35 +1,42 @@
-import re
-import sys
 import argparse
 import os
+import re
+import sys
 import time
+from typing import List
+from urllib.parse import quote, unquote
 
-from bilili.utils.base import repair_filename, touch_dir, touch_file, size_format
-from bilili.utils.playlist import Dpl, M3u
-from bilili.utils.thread import ThreadPool, Flag
-from bilili.utils.console import (Console, Font, Line, String, ProgressBar,
-                                  List, DynamicSymbol, ColorString)
-from bilili.utils.subtitle import Subtitle
-from bilili.utils.attrdict import AttrDict
-from bilili.tools import spider, ass, regex
-from bilili.tools import global_status
-from bilili.handlers.downloader import RemoteFile
-from bilili.handlers.merger import MergingFile
-from bilili.video import BililiContainer
-from bilili.api.subtitle import get_subtitle
-from bilili.api.danmaku import get_danmaku
-from bilili.api.exceptions import (ArgumentsError, CannotDownloadError,
-                                   UnknownTypeError, UnsupportTypeError, IsPreviewError)
+from .__version__ import VERSION as bilili_version
+from .api.danmaku import get_danmaku
+from .api.exceptions import CannotDownloadError, IsPreviewError
+from .api.vip import is_vip
+from .handlers.downloader import RemoteFile
+from .handlers.merger import MergingFile
+from .tools import global_status, regex, spider
+from .utils.base import repair_filename, size_format, touch_dir
+from .utils.console.colorful import set_no_color
+from .utils.console.logger import Badge, Logger, set_logger_debug
+from .utils.console.ui import ColorString, Line, LineList, ProgressBar, String, View
+from .utils.danmaku import convert_xml_danmaku_to_ass
+from .utils.functiontools.attrdict import AttrDict
+from .utils.playlist import Dpl, M3u
+from .utils.subtitle import Subtitle
+from .utils.thread import Flag, ThreadPool
+from .video import BililiContainer
 
 
-def parse_episodes(episodes_str: str, total: int):
+def parse_episodes(episodes_str: str, total: int) -> List[int]:
     """ 将选集字符串转为列表 """
 
-    def reslove_negetive(value):
+    if total == 0:
+        Logger.warning("该剧集列表无任何剧集，猜测正片尚未上线，如果想要下载 PV 等特殊剧集，请添加参数 -s")
+        return []
+
+    def reslove_negetive(value: int) -> int:
         return value if value > 0 else value + total + 1
 
     # 解析字符串为列表
-    print("全 {} 话".format(total))
+    Logger.print("全 {} 话".format(total))
     if re.match(r"([\-\d\^\$]+(~[\-\d\^\$]+)?)(,[\-\d\^\$]+(~[\-\d\^\$]+)?)*", episodes_str):
         episodes_str = episodes_str.replace("^", "1")
         episodes_str = episodes_str.replace("$", "-1")
@@ -60,68 +67,111 @@ def parse_episodes(episodes_str: str, total: int):
         else:
             out_of_range.append(episode)
     if out_of_range:
-        print("warn: 剧集 {} 不存在".format(",".join(list(map(str, out_of_range)))))
+        Logger.warning("剧集 {} 不存在哟！".format(",".join(list(map(str, out_of_range)))))
 
-    print("已选择第 {} 话".format(",".join(list(map(str, episodes)))))
+    Logger.print("已选择第 {} 话".format(",".join(list(map(str, episodes)))))
     assert episodes, "没有选中任何剧集"
     return episodes
 
 
+def check_arguments_and_set_global(args: argparse.Namespace):
+    # 先解码后编码是防止获取到的 SESSDATA 是已经解码后的（包含「,」）
+    # 而番剧无法使用解码后的 SESSDATA
+    cookies = {"SESSDATA": quote(unquote(args.sess_data))}
+    spider.set_cookies(cookies)
+
+    if args.debug:
+        set_logger_debug()
+
+    # 使用 --no-color 或者 NO_COLOR 环境变量非空均不显示颜色
+    if args.no_color or os.environ.get("NO_COLOR") is not None:
+        set_no_color()
+
+    if args.disable_proxy:
+        spider.trust_env = False
+
+    # 大会员身份校验
+    if not args.sess_data:
+        Logger.info("未提供 SESSDATA，无法下载会员专享剧集的喔～")
+    else:
+        if is_vip():
+            Logger.custom("成功以大会员身份登录～", badge=Badge("大会员", fore="white", back="magenta", style="bold"))
+        else:
+            Logger.warning("以非大会员身份登录，无法下载会员专享剧集的喔～")
+
+
 def main():
     """ 解析命令行参数并调用相关模块进行下载 """
 
-    parser = argparse.ArgumentParser(description="bilili B 站视频、弹幕下载器")
+    parser = argparse.ArgumentParser(description="bilili B 站视频、弹幕下载器", prog="bilili")
+    parser.add_argument("-v", "--version", action="version", version="%(prog)s {}".format(bilili_version))
     parser.add_argument("url", help="视频主页地址")
     parser.add_argument(
-        "-t", "--type", default="dash", choices=["flv", "dash", "mp4"], help="选择下载源类型（dash 或 flv 或 mp4）",
+        "-t",
+        "--type",
+        default="dash",
+        choices=["flv", "dash", "mp4"],
+        help="选择下载源类型（dash 或 flv 或 mp4）",
     )
     parser.add_argument("-d", "--dir", default=r"", help="下载目录")
     parser.add_argument(
         "-q",
         "--quality",
-        default=120,
-        choices=[120, 116, 112, 80, 74, 64, 32, 16],
+        default=125,
+        choices=[125, 120, 116, 112, 80, 74, 64, 32, 16],
         type=int,
-        help="视频清晰度 120:4K, 116:1080P60, 112:1080P+, 80:1080P, 74:720P60, 64:720P, 32:480P, 16:360P",
+        help="视频清晰度 125:HDR, 120:4K, 116:1080P60, 112:1080P+, 80:1080P, 74:720P60, 64:720P, 32:480P, 16:360P",
     )
     parser.add_argument("-n", "--num-threads", default=16, type=int, help="最大下载线程数")
     parser.add_argument("-p", "--episodes", default="^~$", help="选集")
+    parser.add_argument("-s", "--with-section", action="store_true", help="同时下载附加剧集（PV、预告以及特别篇等专区内容）")
     parser.add_argument("-w", "--overwrite", action="store_true", help="强制覆盖已下载视频")
-    parser.add_argument("-c", "--sess-data", default=None, help="输入 cookies")
+    parser.add_argument("-c", "--sess-data", default="", help="输入 cookies")
     parser.add_argument("-y", "--yes", action="store_true", help="跳过下载询问")
     parser.add_argument(
-        "--audio-quality", default=30280,
+        "--audio-quality",
+        default=30280,
         choices=[30280, 30232, 30216],
         type=int,
         help="音频码率等级 30280:320kbps, 30232:128kbps, 30216:64kbps",
     )
     parser.add_argument(
-        "--playlist-type", default="dpl", choices=["dpl", "m3u", "no"], help="播放列表类型，支持 dpl 和 m3u，输入 no 不生成播放列表",
+        "--playlist-type",
+        default="dpl",
+        choices=["dpl", "m3u", "no"],
+        help="播放列表类型，支持 dpl 和 m3u，输入 no 不生成播放列表",
     )
     parser.add_argument(
-        "--danmaku", default="xml", choices=["xml", "ass", "no"], help="弹幕类型，支持 xml 和 ass，如果设置为 no 则不下载弹幕",
+        "--danmaku",
+        default="xml",
+        choices=["xml", "ass", "no"],
+        help="弹幕类型，支持 xml 和 ass，如果设置为 no 则不下载弹幕",
     )
     parser.add_argument(
-        "--block-size", default=128, type=int, help="分块下载器的块大小，单位为 MB，默认为 128MB，设置为 0 时禁用分块下载",
+        "--block-size",
+        default=128,
+        type=int,
+        help="分块下载器的块大小，单位为 MiB，默认为 128MiB，设置为 0 时禁用分块下载",
     )
     parser.add_argument("--abs-path", action="store_true", help="修改播放列表路径类型为绝对路径")
     parser.add_argument("--use-mirrors", action="store_true", help="启用从多个镜像下载功能")
     parser.add_argument("--disable-proxy", action="store_true", help="禁用系统代理")
+    parser.add_argument("--no-color", action="store_true", help="不使用颜色")
     parser.add_argument("--debug", action="store_true", help="debug 模式")
 
     args = parser.parse_args()
-    cookies = {"SESSDATA": args.sess_data}
+    check_arguments_and_set_global(args)
 
     config = {
         "url": args.url,
         "dir": args.dir,
         "quality": args.quality,
         "audio_quality": args.audio_quality,
+        "with_section": args.with_section,
         "episodes": args.episodes,
         "playlist_type": args.playlist_type,
         "playlist_path_type": "AP" if args.abs_path else "RP",
         "overwrite": args.overwrite,
-        "cookies": cookies,
         "type": args.type.lower(),
         "block_size": int(args.block_size * 1024 * 1024),
     } >> AttrDict()
@@ -134,11 +184,12 @@ def main():
         "episode_id": "",
         "season_id": "",
     } >> AttrDict()
+    # fmt: on
 
     # fmt: off
     if (avid_match := regex.acg_video.av.origin.match(args.url)) or \
         (avid_match := regex.acg_video.av.short.match(args.url)):
-        from bilili.api.acg_video import get_video_info
+        from .api.acg_video import get_video_info
         avid = avid_match.group("avid")
         if episode_id := get_video_info(avid=avid)["episode_id"]:
             resource_id.episode_id = episode_id
@@ -146,14 +197,14 @@ def main():
             resource_id.avid = avid
     elif (bvid_match := regex.acg_video.bv.origin.match(args.url)) or \
         (bvid_match := regex.acg_video.bv.short.match(args.url)):
-        from bilili.api.acg_video import get_video_info
+        from .api.acg_video import get_video_info
         bvid = bvid_match.group("bvid")
         if episode_id := get_video_info(bvid=bvid)["episode_id"]:
             resource_id.episode_id = episode_id
         else:
             resource_id.bvid = bvid
     elif media_id_match := regex.bangumi.md.origin.match(args.url):
-        from bilili.api.bangumi import get_season_id
+        from .api.bangumi import get_season_id
         media_id = media_id_match.group("media_id")
         resource_id.season_id = get_season_id(media_id=media_id)
     elif (episode_id_match := regex.bangumi.ep.origin.match(args.url)) or \
@@ -165,29 +216,35 @@ def main():
         season_id = season_id_match.group("season_id")
         resource_id.season_id = season_id
     else:
-        print("视频地址有误！")
+        Logger.error("视频地址有误呀，请仔细检查一下下～")
         sys.exit(1)
+    # fmt: on
 
     if resource_id.avid or resource_id.bvid:
-        from bilili.parser.acg_video import get_title, get_list, get_playurl
+        from .parser.acg_video import get_list, get_playurl, get_subtitle, get_title
+
         bili_type = "acg_video"
     elif resource_id.season_id or resource_id.episode_id:
-        from bilili.parser.bangumi import get_title, get_list, get_playurl
+        from .parser.bangumi import get_list, get_playurl, get_subtitle, get_title
+
         bili_type = "bangumi"
+    else:
+        Logger.error("未知的视频类型！")
+        sys.exit(1)
 
     # 获取标题
-    spider.set_cookies(config["cookies"])
-    if args.disable_proxy:
-        spider.trust_env = False
     title = get_title(resource_id)
-    print(title)
+    Logger.print(title)
 
     # 创建所需目录结构
     base_dir = touch_dir(os.path.join(config["dir"], repair_filename(title + " - bilibili")))
     video_dir = touch_dir(os.path.join(base_dir, "Videos"))
 
     # 获取需要的信息
-    containers = [BililiContainer(video_dir=video_dir, type=args.type, **video) for video in get_list(resource_id)]
+    containers = [
+        BililiContainer(video_dir=video_dir, type=args.type, **video)
+        for video in get_list(resource_id, config["with_section"])
+    ]
 
     # 解析并过滤不需要的选集
     episodes = parse_episodes(config["episodes"], len(containers))
@@ -209,73 +266,84 @@ def main():
 
     # 解析片段信息及视频 url
     for i, container in enumerate(containers):
-        print(
-            "{:02}/{:02} parsing segments info...".format(i + 1, len(containers)), end="\r",
+        Logger.print(
+            "{:02}/{:02} 正在努力解析视频信息～".format(i + 1, len(containers)),
+            end="\r",
         )
 
         # 解析视频 url
         try:
             for playinfo in get_playurl(container, config["quality"], config["audio_quality"]):
-                container.append_media(
-                    block_size=config["block_size"],
-                    **playinfo
-                )
+                container.append_media(block_size=config["block_size"], **playinfo)
         except CannotDownloadError as e:
-            print('[warn] {} 无法下载，原因：{}'.format(container.name, e.message))
+            Logger.warning("{} 无法下载，原因：{}".format(container.name, e.message))
+            del containers[i]
+            continue
         except IsPreviewError:
-            print('[warn] {} 是预览视频'.format(container.name))
+            # TODO: 现在还有部分预览的视频吗？
+            Logger.warning("{} 是预览视频呢～".format(container.name))
 
         # 写入播放列表
         if playlist is not None:
             playlist.write_path(container.path)
 
-        # 下载弹幕
-        if bili_type == "acg_video":
-            for sub_info in get_subtitle(avid=resource_id.avid, bvid=resource_id.bvid, cid=container.meta['cid']):
-                sub_path = '{}_{}.srt'.format(os.path.splitext(container.path)[0], sub_info['lang'])
-                subtitle = Subtitle(sub_path)
-                for sub_line in sub_info['lines']:
-                    subtitle.write_line(sub_line["content"], sub_line["from"], sub_line["to"])
+        # 下载字幕
+        for sub_info in get_subtitle(container):
+            sub_path = "{}_{}.srt".format(os.path.splitext(container.path)[0], sub_info["lang"])
+            subtitle = Subtitle(sub_path)
+            for sub_line in sub_info["lines"]:
+                subtitle.write_line(sub_line["content"], sub_line["from"], sub_line["to"])
 
         # 生成弹幕
         if args.danmaku != "no":
-            with open(os.path.splitext(container.path)[0] + ".xml", 'w', encoding='utf-8') as f:
-                f.write(get_danmaku(container.meta['cid']))
+            xml_danmaku = get_danmaku(container.meta["cid"])
+            if args.danmaku == "ass":
+                with open(
+                    os.path.splitext(container.path)[0] + ".ass",
+                    "w",
+                    encoding="utf-8-sig",
+                    errors="replace",
+                ) as f:
+                    f.write(
+                        convert_xml_danmaku_to_ass(
+                            xml_danmaku,
+                            container.height,
+                            container.width,
+                        )
+                    )
+            else:
+                with open(os.path.splitext(container.path)[0] + ".xml", "w", encoding="utf-8") as f:
+                    f.write(xml_danmaku)
 
-        # 转换弹幕为 ASS
-        if args.danmaku == "ass":
-            ass.convert_danmaku_from_xml(
-                os.path.splitext(container.path)[0] + ".xml", container.height, container.width,
-            )
     if playlist is not None:
         playlist.flush()
 
     # 准备下载
     if containers:
         # 状态检查与校正
-        for i, container in enumerate(containers):
+        for i, container in enumerate(containers, 1):
             container_downloaded = not container.check_needs_download(args.overwrite)
-            symbol = "✓" if container_downloaded else "✖"
+            symbol = " " if container_downloaded else "*"
             if container_downloaded:
                 container._.merged = True
-            print("{} {}".format(symbol, str(container)))
+            Logger.print("{}{} {:>2} {}".format("    " * 0, symbol, i, str(container)))
             for media in container.medias:
                 media_downloaded = not media.check_needs_download(args.overwrite) or container_downloaded
-                symbol = "✓" if media_downloaded else "✖"
-                if not container_downloaded:
-                    print("    {} {}".format(symbol, media.name))
+                symbol = " " if media_downloaded else "*"
+                if not container_downloaded and args.debug:
+                    Logger.print("{}{} {}".format("    " * 1, symbol, media.name))
                 for block in media.blocks:
                     block_downloaded = not block.check_needs_download(args.overwrite) or media_downloaded
-                    symbol = "✓" if block_downloaded else "✖"
+                    symbol = " " if block_downloaded else "*"
                     block._.downloaded = block_downloaded
                     if not media_downloaded and args.debug:
-                        print("        {} {}".format(symbol, block.name))
+                        Logger.print("{}{} {}".format("    " * 2, symbol, block.name))
 
         # 询问是否下载，通过参数 -y 可以跳过
         if not args.yes:
             answer = None
             while answer is None:
-                result = input("以上标 ✖ 为需要进行下载的视频，是否立刻进行下载？[Y/n]")
+                result = input("以上标 * 为需要进行下载的视频，是否立刻进行下载？[Y/n]")
                 if result == "" or result[0].lower() == "y":
                     answer = True
                 elif result[0].lower() == "n":
@@ -289,12 +357,21 @@ def main():
         merge_wait_flag = Flag(False)  # 合并线程池不能因为没有任务就结束
         # 因此要设定一个 flag，待最后合并结束后改变其值
         merge_pool = ThreadPool(3, wait=merge_wait_flag, daemon=True)
-        download_pool = ThreadPool(args.num_threads, daemon=True, thread_globals_creator={
-            "thread_spider":spider.clone            # 为每个线程创建一个全新的 Session，因为 requests.Session 不是线程安全的
-                                                    # https://github.com/psf/requests/issues/1871
-        })
+        download_pool = ThreadPool(
+            args.num_threads,
+            daemon=True,
+            thread_globals_creator={
+                # 为每个线程创建一个全新的 Session，因为 requests.Session 不是线程安全的
+                # https://github.com/psf/requests/issues/1871
+                "thread_spider": spider.clone
+            },
+        )
         for container in containers:
-            merging_file = MergingFile(container.type, [media.path for media in container.medias], container.path,)
+            merging_file = MergingFile(
+                container.type,
+                [media.path for media in container.medias],
+                container.path,
+            )
             for media in container.medias:
 
                 block_merging_file = MergingFile(None, [block.path for block in media.blocks], media.path)
@@ -313,7 +390,9 @@ def main():
                         status.size = file.size
 
                     @remote_file.on("downloaded")
-                    def downloaded(file, status=block._, merging_file=merging_file, block_merging_file=block_merging_file):
+                    def downloaded(
+                        file, status=block._, merging_file=merging_file, block_merging_file=block_merging_file
+                    ):
                         status.downloaded = True
 
                         if status.parent.downloaded:
@@ -348,22 +427,30 @@ def main():
         download_pool.run()
 
         # 初始化界面
-        console = Console(debug=args.debug)
-        console.add_component(Line(center=Font(char_a="𝓪", char_A="𝓐"), fillchar=" "))
+        console = View(debug=args.debug)
+        console.add_component(Line(center=String(), fillchar=" "))
         console.add_component(Line(left=ColorString(fore="cyan"), fillchar=" "))
-        console.add_component(List(Line(left=String(), right=String(), fillchar="-")))
+        console.add_component(LineList(Line(left=String(), right=String(), fillchar="-")))
         console.add_component(
             Line(
-                left=ColorString(fore="green", back="white", subcomponent=ProgressBar(symbols=" ▏▎▍▌▋▊▉█", width=65),),
+                left=ColorString(
+                    fore="green",
+                    back="white",
+                    subcomponent=ProgressBar(symbols=" ▏▎▍▌▋▊▉█", width=65),
+                ),
                 right=String(),
                 fillchar=" ",
             )
         )
         console.add_component(Line(left=ColorString(fore="blue"), fillchar=" "))
-        console.add_component(List(Line(left=String(), right=DynamicSymbol(symbols="🌑🌒🌓🌔🌕🌖🌗🌘"), fillchar=" ")))
+        console.add_component(LineList(Line(left=String(), fillchar=" ")))
         console.add_component(
             Line(
-                left=ColorString(fore="yellow", back="white", subcomponent=ProgressBar(symbols=" ▏▎▍▌▋▊▉█", width=65),),
+                left=ColorString(
+                    fore="yellow",
+                    back="white",
+                    subcomponent=ProgressBar(symbols=" ▏▎▍▌▋▊▉█", width=65),
+                ),
                 right=String(),
                 fillchar=" ",
             )
@@ -385,10 +472,10 @@ def main():
                 # fmt: off
                 [
                     {
-                        "center": " 🍻 bilili ",
+                        "center": " bilili ",
                     },
                     {
-                        "left": "🌠 Downloading videos: "
+                        "left": "Downloading videos: "
                     } if global_status.downloading else None,
                     [
                         {
@@ -401,14 +488,14 @@ def main():
                     ] if global_status.downloading else None,
                     {
                         "left": global_status.size / global_status.total_size,
-                        "right": " {}/{} {}/s ⚡".format(
+                        "right": " {}/{} {}/s".format(
                             size_format(global_status.size),
                             size_format(global_status.total_size),
                             size_format(speed),
                         ),
                     } if global_status.downloading else None,
                     {
-                        "left": "🍰 Merging videos: "
+                        "left": "Merging videos: "
                     } if global_status.merging else None,
                     [
                         {
@@ -419,11 +506,12 @@ def main():
                     ] if global_status.merging else None,
                     {
                         "left": sum([container._.merged for container in containers]) / len(containers),
-                        "right": " {}/{} 🚀".format(
+                        "right": " {}/{}".format(
                             sum([container._.merged for container in containers]), len(containers),
                         ),
                     } if global_status.merging else None,
                 ]
+                # fmt: on
             )
 
             # 检查是否已经全部完成
@@ -437,10 +525,11 @@ def main():
                 refresh_rate = 2
                 time.sleep(max(1 / refresh_rate - (time.time() - now_t), 0.01))
             except (SystemExit, KeyboardInterrupt):
-                raise
-        print("已全部下载完成！")
+                Logger.info("已终止下载，再次运行即可继续下载～")
+                sys.exit(1)
+        Logger.info("已全部下载完成啦！")
     else:
-        print("没有需要下载的视频！")
+        Logger.info("没有需要下载的视频！")
 
 
 if __name__ == "__main__":
