@@ -1,59 +1,49 @@
+import json
 import re
 
-from bilili.tools import spider, regex_bangumi_ep
-from bilili.quality import gen_quality_sequence, video_quality_map, Media
-from bilili.utils.base import touch_url
-from bilili.api.exceptions import (
-    ArgumentsError,
-    CannotDownloadError,
-    UnknownTypeError,
-    UnsupportTypeError,
-)
-from bilili.api.exports import export_api
+from ..api.exceptions import ArgumentsError, CannotDownloadError, UnknownTypeError, UnsupportTypeError
+from ..quality import Media, gen_quality_sequence, video_quality_map
+from ..tools import regex_bangumi_ep, spider
+from ..utils.base import touch_url
+from .utils import MaxRetry
 
 
-@export_api(route="/video_info")
+@MaxRetry(2)
 def get_video_info(avid: str = "", bvid: str = ""):
     if not (avid or bvid):
         raise ArgumentsError("avid", "bvid")
     info_api = "http://api.bilibili.com/x/web-interface/view?aid={avid}&bvid={bvid}"
-    res = spider.get(info_api.format(avid=avid, bvid=bvid))
+    res = spider.get(info_api.format(avid=avid, bvid=bvid), timeout=3)
     res_json_data = res.json()["data"]
     episode_id = ""
-    if res_json_data.get("redirect_url") and regex_bangumi_ep.match(res_json_data["redirect_url"]):
-        episode_id = regex_bangumi_ep.match(res_json_data["redirect_url"]).group("episode_id")
+    if res_json_data.get("redirect_url") and (match_obj := regex_bangumi_ep.match(res_json_data["redirect_url"])):
+        episode_id = match_obj.group("episode_id")
     return {
         "avid": str(res_json_data["aid"]),
         "bvid": res_json_data["bvid"],
+        "title": res_json_data["title"],
         "picture": res_json_data["pic"],
         "episode_id": episode_id,
     }
 
 
-@export_api(route="/acg_video/title")
 def get_acg_video_title(avid: str = "", bvid: str = "") -> str:
     if not (avid or bvid):
         raise ArgumentsError("avid", "bvid")
-    home_url = (
-        "https://www.bilibili.com/video/{bvid}".format(bvid=bvid)
-        if bvid
-        else "https://www.bilibili.com/video/av{avid}".format(avid=avid)
-    )
-    res = spider.get(home_url)
-    regex_title = re.compile(r"<title .*>(.*)_哔哩哔哩 \(゜-゜\)つロ 干杯~-bilibili</title>")
-    if regex_title.search(res.text):
-        title = regex_title.search(res.text).group(1)
-    else:
+    try:
+        title = get_video_info(avid=avid, bvid=bvid)["title"]
+    except:
         title = "呐，我也不知道是什么标题呢～"
-    return title
+    finally:
+        return title
 
 
-@export_api(route="/acg_video/list")
+@MaxRetry(2)
 def get_acg_video_list(avid: str = "", bvid: str = ""):
     if not (avid or bvid):
         raise ArgumentsError("avid", "bvid")
     list_api = "https://api.bilibili.com/x/player/pagelist?aid={avid}&bvid={bvid}&jsonp=jsonp"
-    res = spider.get(list_api.format(avid=avid, bvid=bvid))
+    res = spider.get(list_api.format(avid=avid, bvid=bvid), timeout=3)
     return [
         # fmt: off
         {
@@ -62,12 +52,18 @@ def get_acg_video_list(avid: str = "", bvid: str = ""):
             'cid': str(item['cid'])
         }
         for i, item in enumerate(res.json()['data'])
+        # fmt: on
     ]
 
 
-@export_api(route="/acg_video/playurl")
+@MaxRetry(2)
 def get_acg_video_playurl(
-    avid: str = "", bvid: str = "", cid: str = "", quality: int = 120, audio_quality: int = 30280, type: str = "dash"
+    avid: str = "",
+    bvid: str = "",
+    cid: str = "",
+    quality: int = 125,
+    audio_quality: int = 30280,
+    type: str = "dash",
 ):
     if not (avid or bvid):
         raise ArgumentsError("avid", "bvid")
@@ -77,7 +73,7 @@ def get_acg_video_playurl(
         "https://api.bilibili.com/x/player/playurl?avid={avid}&bvid={bvid}&cid={cid}&qn={quality}&type=&otype=json"
     )
     if type == "flv":
-        touch_message = spider.get(play_api.format(avid=avid, bvid=bvid, cid=cid, quality=80)).json()
+        touch_message = spider.get(play_api.format(avid=avid, bvid=bvid, cid=cid, quality=80), timeout=3).json()
         if touch_message["code"] != 0:
             raise CannotDownloadError(touch_message["code"], touch_message["message"])
 
@@ -87,7 +83,7 @@ def get_acg_video_playurl(
                 break
 
         play_url = play_api.format(avid=avid, bvid=bvid, cid=cid, quality=quality)
-        res = spider.get(play_url)
+        res = spider.get(play_url, timeout=3)
 
         return [
             {
@@ -104,9 +100,9 @@ def get_acg_video_playurl(
         ]
     elif type == "dash":
         result = []
-        play_api_dash = play_api + "&fnver=0&fnval=16&fourk=1"
+        play_api_dash = play_api + "&fnver=0&fnval=80&fourk=1"
         touch_message = spider.get(
-            play_api_dash.format(avid=avid, bvid=bvid, cid=cid, quality=video_quality_sequence[0])
+            play_api_dash.format(avid=avid, bvid=bvid, cid=cid, quality=video_quality_sequence[0]), timeout=3
         ).json()
 
         if touch_message["code"] != 0:
@@ -119,7 +115,7 @@ def get_acg_video_playurl(
             if video_quality in video_accept_quality:
                 break
         else:
-            video_quality = 120
+            video_quality = 125
 
         audio_accept_quality = set([audio["id"] for audio in touch_message["data"]["dash"]["audio"]])
         for audio_quality in audio_quality_sequence:
@@ -128,7 +124,7 @@ def get_acg_video_playurl(
         else:
             audio_quality = 30280
 
-        res = spider.get(play_api_dash.format(avid=avid, bvid=bvid, cid=cid, quality=quality))
+        res = spider.get(play_api_dash.format(avid=avid, bvid=bvid, cid=cid, quality=quality), timeout=3)
 
         if res.json()["data"]["dash"]["video"]:
             videos = res.json()["data"]["dash"]["video"]
@@ -167,7 +163,7 @@ def get_acg_video_playurl(
         return result
     elif type == "mp4":
         play_api_mp4 = play_api + "&platform=html5&high_quality=1"
-        play_info = spider.get(play_api_mp4.format(avid=avid, bvid=bvid, cid=cid, quality=120)).json()
+        play_info = spider.get(play_api_mp4.format(avid=avid, bvid=bvid, cid=cid, quality=120), timeout=3).json()
         if play_info["code"] != 0:
             raise CannotDownloadError(play_info["code"], play_info["message"])
         return [
@@ -184,3 +180,22 @@ def get_acg_video_playurl(
         ]
     else:
         raise UnknownTypeError(type)
+
+
+@MaxRetry(2)
+def get_acg_video_subtitle(avid: str = "", bvid: str = "", cid: str = ""):
+    if not (avid or bvid):
+        raise ArgumentsError("avid", "bvid")
+    subtitle_api = "https://api.bilibili.com/x/player.so?id=cid:{cid}&aid={avid}&bvid={bvid}"
+    subtitle_url = subtitle_api.format(avid=avid, cid=cid, bvid=bvid)
+    res = spider.get(subtitle_url, timeout=3)
+    subtitles_info = json.loads(re.search(r"<subtitle>(.+)</subtitle>", res.text).group(1))
+    return [
+        # fmt: off
+        {
+            "lang": sub_info["lan_doc"],
+            "lines": spider.get("https:" + sub_info["subtitle_url"], timeout=(3, 10)).json()["body"]
+        }
+        for sub_info in subtitles_info["subtitles"]
+        # fmt: on
+    ]
