@@ -1,14 +1,18 @@
 import os
+from typing import Callable, List
 
-from bilili.handlers.base import Handler
-from bilili.utils.ffmpeg import FFmpeg
-
+from ..handlers.base import Handler
+from ..utils.console.logger import Logger
+from ..utils.ffmpeg import FFmpeg
 
 ffmpeg = FFmpeg()
 
 
 class MergingFile(Handler):
-    def __init__(self, type, src_path_list=[], dst_path=""):
+    before_merge: Callable[..., None]
+    merged: Callable[..., None]
+
+    def __init__(self, type: str, src_path_list: List[str] = [], dst_path: str = ""):
         super().__init__(["before_merge", "merged"])
         self.type = type
         self.src_path_list = src_path_list
@@ -29,7 +33,7 @@ class MergingFile(Handler):
             else:
                 ffmpeg.convert(self.src_path_list[0], self.dst_path)
         else:
-            print("Unknown type {}".format(self.type))
+            Logger.error("未知类型： {}".format(self.type))
         for src_path in self.src_path_list:
             os.remove(src_path)
         self.merged(self)
