@@ -1,24 +1,24 @@
-import os
-from bilili.api.acg_video import get_acg_video_title, get_acg_video_list, get_acg_video_playurl
+from ..api.acg_video import get_acg_video_list, get_acg_video_playurl, get_acg_video_subtitle, get_acg_video_title
 
 
 def get_title(resource_id):
     return get_acg_video_title(avid=resource_id.avid, bvid=resource_id.bvid)
 
 
-def get_list(resource_id):
+def get_list(resource_id, with_section: bool = False):
     video_list = get_acg_video_list(avid=resource_id.avid, bvid=resource_id.bvid)
     return [
+        # fmt: off
         {
             "id": video["id"],
             "name": video["name"],
-            # fmt: off
             "meta": {
                 "avid": resource_id.avid,
                 "bvid": resource_id.bvid,
                 "cid": video["cid"]
             },
         }
+        # fmt: on
         for video in video_list
     ]
 
@@ -45,3 +45,11 @@ def get_playurl(container, quality, audio_quality):
         }
         for play_info in play_list
     ]
+
+
+def get_subtitle(container):
+    return get_acg_video_subtitle(
+        avid=container.meta["avid"],
+        bvid=container.meta["bvid"],
+        cid=container.meta["cid"],
+    )
