@@ -1,17 +1,19 @@
-from bilili.api.bangumi import get_bangumi_title, get_bangumi_list, get_bangumi_playurl
+from ..api.bangumi import get_bangumi_list, get_bangumi_playurl, get_bangumi_subtitle, get_bangumi_title
 
 
 def get_title(resource_id):
     return get_bangumi_title(season_id=resource_id.season_id, episode_id=resource_id.episode_id)
 
 
-def get_list(resource_id):
-    video_list = get_bangumi_list(season_id=resource_id.season_id, episode_id=resource_id.episode_id)
+def get_list(resource_id, with_section: bool = False):
+    video_list = get_bangumi_list(
+        season_id=resource_id.season_id, episode_id=resource_id.episode_id, with_section=with_section
+    )
     return [
+        # fmt: off
         {
             "id": video["id"],
             "name": video["name"],
-            # fmt: off
             "meta": {
                 "avid": video["avid"],
                 "bvid": video["bvid"],
@@ -19,6 +21,7 @@ def get_list(resource_id):
                 "episode_id": video["episode_id"]
             },
         }
+        # fmt: on
         for video in video_list
     ]
 
@@ -45,3 +48,11 @@ def get_playurl(container, quality, audio_quality):
         }
         for play_info in play_list
     ]
+
+
+def get_subtitle(container):
+    return get_bangumi_subtitle(
+        avid=container.meta["avid"],
+        bvid=container.meta["bvid"],
+        cid=container.meta["cid"],
+    )
