@@ -7,62 +7,67 @@ class Media(Enum):
     AUDIO = 30200
 
 
-video_quality_sequence_default = [120, 116, 112, 80, 74, 64, 32, 16]
+video_quality_sequence_default = [125, 120, 116, 112, 80, 74, 64, 32, 16]
 audio_quality_sequence_default = [30280, 30232, 30216]
 
 video_quality_map = {
+    125: {
+        "description": "HDR 真彩",
+        "width": 3840,
+        "height": 1920,
+    },
     120: {
-        "description": "超清 4K",
-        "width": 4096,
-        "height": 2160,
+        "description": "4K 超清",
+        "width": 3840,
+        "height": 1920,
     },
     116: {
-        "description": "高清 1080P60",
-        "width": 1920,
+        "description": "1080P 60帧",
+        "width": 2160,
         "height": 1080,
     },
     112: {
-        "description": "高清 1080P+",
-        "width": 1920,
+        "description": "1080P 高码率",
+        "width": 2160,
         "height": 1080,
     },
     80: {
-        "description": "高清 1080P",
-        "width": 1920,
+        "description": "1080P 高清",
+        "width": 2160,
         "height": 1080,
     },
     74: {
-        "description": "高清 720P60",
-        "width": 1280,
+        "description": "720P 60帧",
+        "width": 1440,
         "height": 720,
     },
     64: {
-        "description": "高清 720P",
-        "width": 1280,
+        "description": "720P 高清",
+        "width": 1440,
         "height": 720,
     },
     32: {
-        "description": "清晰 480P",
-        "width": 640,
+        "description": "480P 清晰",
+        "width": 960,
         "height": 480,
     },
     16: {
-        "description": "流畅 360P",
-        "width": 480,
+        "description": "360P 流畅",
+        "width": 720,
         "height": 360,
     },
     6: {
-        "description": "极速 240P",
+        "description": "240P 极速",
         "width": 320,
         "height": 240,
     },
     208: {
-        "description": "高清 1080P",
+        "description": "1080P 高清",
         "width": 1920,
         "height": 1080,
     },
     192: {
-        "description": "高清 720P",
+        "description": "720P 高清",
         "width": 1280,
         "height": 720,
     },
