@@ -1,10 +1,8 @@
 import re
 
-from bilili.utils.crawler import BililiCrawler
-from bilili.utils.danmaku import ASS
-from bilili.handlers.status import DownloaderStatus
-from bilili.utils.attrdict import AttrDict
-
+from .handlers.status import DownloaderStatus
+from .utils.crawler import BililiCrawler
+from .utils.functiontools.attrdict import AttrDict
 
 # avid
 regex_acg_video_av = re.compile(r"https?://(www\.|m\.)?bilibili\.com/video/av(?P<avid>\d+)")
@@ -27,7 +25,6 @@ regex_bangumi_ss_short = re.compile(r"https?://b23\.tv/ss(?P<season_id>\d+)")
 
 
 spider = BililiCrawler()
-ass = ASS()
 global_status = DownloaderStatus()
 # fmt: off
 regex = {
@@ -55,3 +52,4 @@ regex = {
         },
     },
 } >> AttrDict()
+# fmt: on
