@@ -3,7 +3,7 @@ import queue
 import threading
 
 
-from bilili.utils.base import Ref
+from ..utils.base import Ref
 
 
 class Flag(Ref):
@@ -32,7 +32,7 @@ class Task:
 
 
 class ThreadPool:
-    """ 线程池类
+    """线程池类
     快速创建多个相同任务的线程池
     """
 
