@@ -1,13 +1,11 @@
 import os
-import re
-import time
-import math
-import subprocess
 
-from bilili.handlers.status import DownloaderStatus
-from bilili.quality import video_quality_map, audio_quality_map
-from bilili.tools import global_status
-from bilili.utils.base import repair_filename
+from .handlers.status import DownloaderStatus
+from .quality import audio_quality_map, video_quality_map
+from .tools import global_status
+from .utils.base import repair_filename
+from .utils.console.logger import Logger
+from .utils.console.colorful import colored_string
 
 
 class BililiContainer:
@@ -39,18 +37,24 @@ class BililiContainer:
         quality_description: str = ""
         if self.type == "dash":
             quality_description = " & ".join(
+                # fmt: off
                 [
-                    {"dash_video": video_quality_map, "dash_audio": audio_quality_map}[media.type][media.quality][
-                        "description"
-                    ]
+                    {
+                        "dash_video": video_quality_map,
+                        "dash_audio": audio_quality_map
+                    }[media.type][media.quality]["description"]
                     for media in self.medias
                 ]
+                # fmt: on
             )
         else:
+            assert self.quality is not None, "quality 仍然为 None"
             quality_description = video_quality_map[self.quality]["description"]
-        return "{} 「{}」".format(self.name, quality_description)
+        return "{} 「{}」".format(
+            colored_string(self.name, fore="magenta"), colored_string(quality_description, fore="cyan")
+        )
 
-    def check_needs_download(self, overwrite=False):
+    def check_needs_download(self, overwrite: bool = False):
         """ 检查是否需要下载 """
         if overwrite:
             if os.path.exists(self.path):
@@ -66,7 +70,19 @@ class BililiMedia:
     从 B 站直接获取的可下载的媒体单元，可能是 flv、mp4、m4s
     """
 
-    def __init__(self, id, url, quality, size, height, width, container, mirrors=[], type="dash_video", block_size=0):
+    def __init__(
+        self,
+        id,
+        url,
+        quality,
+        size,
+        height,
+        width,
+        container,
+        mirrors=[],
+        type="dash_video",
+        block_size=0,
+    ):
 
         self.id = id
         self.quality = quality
@@ -85,7 +101,7 @@ class BililiMedia:
         elif self.container.type == "mp4":
             self.path += "_dl.mp4"
         else:
-            print("[warn] Unknown container type: {}".format(self.container.type))
+            Logger.warning("未知的容器类型：{}".format(self.container.type))
         self.name = os.path.split(self.path)[-1]
         self._ = DownloaderStatus(parent=self.container._)
         self._.total_size = size
@@ -97,10 +113,10 @@ class BililiMedia:
         if self.container.height is None:
             self.container.height = height
         if self._.total_size == 0:
-            print("[warn] {} 获取 size 为 0".format(self.name))
+            Logger.warning("{} 获取 size 为 0".format(self.name))
             self._.total_size = 0
         if self._.total_size is None:
-            print("[warn] {} 无法获取 size".format(self.name))
+            Logger.warning("{} 无法获取 size".format(self.name))
             self._.total_size = 0
 
         self.blocks = self.chunking()
@@ -112,13 +128,21 @@ class BililiMedia:
         if block_size:
             block_range_list = [(i, i + block_size - 1) for i in range(0, total_size, block_size)]
             if total_size % block_size != 0:
-                block_range_list[-1] = (total_size // block_size * block_size, total_size - 1)
+                block_range_list[-1] = (
+                    total_size // block_size * block_size,
+                    total_size - 1,
+                )
         else:
             block_range_list = [(0, total_size - 1)]
         for i, block_range in enumerate(block_range_list):
             blocks.append(
                 BililiBlock(
-                    id=i, url=self.url, mirrors=self.mirrors, media=self, block_size=block_size, range=block_range
+                    id=i,
+                    url=self.url,
+                    mirrors=self.mirrors,
+                    media=self,
+                    block_size=block_size,
+                    range=block_range,
                 )
             )
         assert self._.total_size == total_size, "重新设置的 total size 与原来值不匹配"
